@@ -1,5 +1,6 @@
 #-*- coding:utf-8 -*-
-from StringIO import StringIO
+from __future__ import unicode_literals
+from six import StringIO, PY3
 
 from django.test import TestCase
 
@@ -59,15 +60,17 @@ class TestCSVRenderer (TestCase):
     def test_tablize_a_list_with_unicode_elements(self):
         renderer = CSVRenderer()
 
-        flat = renderer.tablize([{u'a': 1, u'b': u'hello\u2014goodbye'}])
-        self.assertEqual(flat, [[u'a', u'b'            ],
-                                [1   , u'hello—goodbye']])
+        flat = renderer.tablize([{'a': 1, 'b': 'hello\u2014goodbye'}])
+        self.assertEqual(flat, [['a', 'b'            ],
+                                [1   , 'hello—goodbye']])
 
     def test_render_a_list_with_unicode_elements(self):
         renderer = CSVRenderer()
 
-        dump = renderer.render([{u'a': 1, u'b': u'hello\u2014goodbye', u'c': 'http://example.com/'}])
-        self.assertEqual(dump, (u'a,b,c\r\n1,hello—goodbye,http://example.com/\r\n').encode('utf-8'))
+        dump = renderer.render([{'a': 1, 'b': 'hello\u2014goodbye', 'c': 'http://example.com/'}])
+        if PY3:
+            dump = dump.encode('utf-8')
+        self.assertEqual(dump, ('a,b,c\r\n1,hello—goodbye,http://example.com/\r\n').encode('utf-8'))
 
     def test_render_ordered_rows(self):
         parser = CSVParser()
@@ -104,7 +107,8 @@ class TestCSVParser(TestCase):
         parser = CSVParser()
         csv_file = 'v1;v2;v3\r\na;1;2.3\r\nb;4;5.6\r\n'
 
-        data = parser.parse(StringIO(csv_file), parser_context={'delimiter': ';'})
+        delimiter = ';' if PY3 else b';'
+        data = parser.parse(StringIO(csv_file), parser_context={'delimiter': delimiter})
 
         self.assertEqual(data, [{'v1': 'a', 'v2': '1', 'v3': '2.3'},
                                 {'v1': 'b', 'v2': '4', 'v3': '5.6'}])        
